@@ -279,7 +279,9 @@ def upload_file(
                 return
         pp = str(Path(path_in_dataset).parent)
         new_dataset_files.append(DatasetFile("", object_key, 0, _norm_path(pp)))
-    _update_dataset(id, new_dataset_files, token=token)
+    _update_dataset(
+        id, new_dataset_files, commit_message=f"添加文件 {path_in_dataset}", token=token
+    )
 
 
 def _norm_path(pp: str) -> str:
@@ -359,7 +361,12 @@ def upload_folder(
         # skip update if no files in directory
         return
     # print(new_dataset_files)
-    _update_dataset(id, list(new_dataset_files), token=token)
+    _update_dataset(
+        id,
+        list(new_dataset_files),
+        commit_message=f"添加目录 {folder_in_dataset}",
+        token=token,
+    )
 
 
 def _init_cache(cache_dir: Optional[str | Path] = None) -> Path:
@@ -477,7 +484,7 @@ def download_dir(
     headers = {
         "x-kesci-token": token,
     }
-    if commit is  None:
+    if commit is None:
         commit = dataset_detail.commits[-1]._id
     params = {"Version": commit}
     response = requests.get(url, headers=headers, params=params, timeout=10)
@@ -595,7 +602,7 @@ def download_file(
     headers = {
         "x-kesci-token": token,
     }
-    if commit is  None:
+    if commit is None:
         commit = dataset_detail.commits[-1]._id
     params = {"Version": commit}
     response = requests.get(url, headers=headers, params=params, timeout=10)
@@ -676,7 +683,12 @@ def delete_file(
         else:
             print(f"delete file {file.path_in_dataset()}")
             continue
-    _update_dataset(id, new_dataset_files, token=token)
+    _update_dataset(
+        id,
+        new_dataset_files,
+        commit_message=f"删除文件 {filepath_in_dataset}",
+        token=token,
+    )
     return
 
 
